==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFilteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringEventArgsDetailDescriptionMetadata } from "./WebFilteringEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDescription } from "./WebFilteringEventArgsDescription";
/**
 * @hidden
 */
export let WebFilteringEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringEventArgsDescriptionMetadata.a == null) {
                WebFilteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringEventArgsDescriptionMetadata.c(WebFilteringEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebFilteringEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringEventArgsDescriptionMetadata.a);
            WebFilteringEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebFilteringEventArgsDetail");
        }
        static d(a) {
            WebFilteringEventArgsDescriptionMetadata.b(a);
            a.aa("WebFilteringEventArgs", () => new WebFilteringEventArgsDescription());
            a.z("WebFilteringEventArgs", WebFilteringEventArgsDescriptionMetadata.a);
        }
    }
    WebFilteringEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringEventArgsDescriptionMetadata, 'WebFilteringEventArgsDescriptionMetadata');
    WebFilteringEventArgsDescriptionMetadata.a = null;
    return WebFilteringEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringEventArgsDetailDescriptionMetadata } from "./WebFilteringEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDescription } from "./WebFilteringEventArgsDescription";
/**
 * @hidden
 */
export let WebFilteringEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringEventArgsDescriptionMetadata.a == null) {
                WebFilteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringEventArgsDescriptionMetadata.c(WebFilteringEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFilteringEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringEventArgsDescriptionMetadata.a);
            WebFilteringEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebFilteringEventArgsDetail");
        }
        static d(a) {
            WebFilteringEventArgsDescriptionMetadata.b(a);
            a.ac("WebFilteringEventArgs", () => new WebFilteringEventArgsDescription());
            a.ab("WebFilteringEventArgs", WebFilteringEventArgsDescriptionMetadata.a);
        }
    }
    WebFilteringEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringEventArgsDescriptionMetadata, 'WebFilteringEventArgsDescriptionMetadata');
    WebFilteringEventArgsDescriptionMetadata.a = null;
    return WebFilteringEventArgsDescriptionMetadata;
})();
